summaryrefslogtreecommitdiffstats
path: root/chrome/browser/automation/automation_provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/automation/automation_provider.h')
-rw-r--r--chrome/browser/automation/automation_provider.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/automation/automation_provider.h b/chrome/browser/automation/automation_provider.h
index 8d62914..2849cd1 100644
--- a/chrome/browser/automation/automation_provider.h
+++ b/chrome/browser/automation/automation_provider.h
@@ -430,10 +430,10 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
void GetWindowTitle(int handle, string16* text);
// Convert a tab handle into a WebContents. If |tab| is non-NULL a pointer
// to the tab is also returned. Returns NULL in case of failure or if the tab
- // is not of the WebContents type.
- WebContents* GetWebContentsForHandle(int handle, NavigationController** tab);
+ // is not of the TabContents type.
+ TabContents* GetTabContentsForHandle(int handle, NavigationController** tab);
ExternalTabContainer* GetExternalTabForHandle(int handle);
@@ -430,10 +430,10 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
void GetWindowTitle(int handle, string16* text);
- // Convert a tab handle into a WebContents. If |tab| is non-NULL a pointer
+ // Convert a tab handle into a TabContents. If |tab| is non-NULL a pointer
// to the tab is also returned. Returns NULL in case of failure or if the tab